@@ -1,21 +1,24 @@
 # -*- coding: utf-8 -*-
+from colorama import Fore
+from colorama import Style
+from datetime import date
+from lxml import etree
+from mrbob import hooks
+from mrbob.bobexceptions import MrBobError
+from mrbob.bobexceptions import SkipQuestion
+from mrbob.bobexceptions import ValidationError
+from mrbob.rendering import jinja2_env
+from six.moves import input
+
+import case_conversion as cc
 import codecs
 import keyword
 import os
-import re
+import six
 import string
 import subprocess
 import sys
-from datetime import date
 
-import case_conversion as cc
-import six
-from colorama import Fore, Style
-from lxml import etree
-from mrbob import hooks
-from mrbob.bobexceptions import MrBobError, SkipQuestion, ValidationError
-from mrbob.rendering import jinja2_env
-from six.moves import input
 
 try:
     from ConfigParser import ConfigParser
@@ -181,7 +184,7 @@ def check_klass_name(configurator, question, answer):
         raise ValidationError(
             "{key} is a reserved Python keyword".format(key=answer)
         )  # NOQA: E501
-    if not re.match("[a-zA-Z_][a-zA-Z0-9_]*$", answer):
+    if not answer.isidentifier():
         raise ValidationError(
             "{key} is not a valid class identifier".format(key=answer)
         )  # NOQA: E501
@@ -193,7 +196,7 @@ def check_method_name(configurator, question, answer):
         raise ValidationError(
             "{key} is a reserved Python keyword".format(key=answer)
         )  # NOQA: E501
-    if not re.match("[a-zA-Z_][a-zA-Z0-9_]*$", answer):
+    if not answer.isidentifier():
         raise ValidationError(
             "{key} is not a valid method identifier".format(key=answer)
         )  # NOQA: E501
@@ -270,6 +273,10 @@ def validate_packagename(configurator):
     if package_dir.startswith(".") or package_dir.endswith("."):
         fail = True
 
+    for namespace in package_dir.replace("-", "_").split("."):
+        if keyword.iskeyword(namespace) or not namespace.isidentifier():
+            fail = True
+
     if fail:
         msg = (
             "Error: '{0}' is not a valid packagename.\n"
